diff --git a/common/debug.go b/common/debug.go
index 61acd8ce70f8b77e4b4ffb581e996d69fef48e03..28c52b4a9cd51cb64f2b5b31f8de9ddf586a8a91 100644
--- a/common/debug.go
+++ b/common/debug.go
@@ -37,8 +37,8 @@ func Report(extra ...interface{}) {
 	fmt.Fprintln(os.Stderr, "#### BUG! PLEASE REPORT ####")
 }
 
-// PrintDepricationWarning prinst the given string in a box using fmt.Println.
-func PrintDepricationWarning(str string) {
+// PrintDeprecationWarning prints the given string in a box using fmt.Println.
+func PrintDeprecationWarning(str string) {
 	line := strings.Repeat("#", len(str)+4)
 	emptyLine := strings.Repeat(" ", len(str))
 	fmt.Printf(`